@@ -37,12 +37,12 @@
 
 #define VERLINES 7							/* number of lines in this vanity text */
 #define VER1 "## dgamelaunch - network console game launcher\n"
-#define VER2 "## version 1.3.9\n"
+#define VER2 "## version 1.3.10\n"
 #define VER3 "## \n"
 #define VER4 "## (c)2001-3 M. Drew Streib. This program's source is released under the GPL.\n"
 #define VER5 "## Send mail to <dtype@dtype.org> for details or a copy of the source code.\n"
 #define VER6 "## ** Games on this server are recorded for in-progress viewing and playback!\n"
-#define VER7 "## Server info is at http://dtype.org/nethack/"
+#define VER7 "## Server info is at http://alt.org/nethack/"
 
 /* ************************************************************* */
 /* ************************************************************* */
@@ -153,7 +153,7 @@ gen_inprogress_lock ()
 	strcat (lockfile, ":");
 	strcat (lockfile, ttyrec_filename);
 
-	fd = open (lockfile, O_WRONLY | O_CREAT);
+	fd = open (lockfile, O_WRONLY | O_CREAT, 0644);
 	if (flock (fd, LOCK_EX))
 		exit (68);
 }
@@ -677,7 +677,7 @@ readfile (int nolock)
 				{
 					f_email[f_num][(b - n)] = *b;
 					b++;
-					if ((b - n) >= 80)
+					if ((b - n) > 80)
 						exit (101);
 				}
 
